@@ -108,6 +108,9 @@ AcqFunctionEHVIGH = R6Class("AcqFunctionEHVIGH",
     update = function() {
       n_obj = length(self$archive$cols_y)
       ys = self$archive$data[, self$archive$cols_y, with = FALSE]
+      if (self$surrogate$output_trafo_must_be_considered) {
+        ys = self$surrogate$output_trafo$transform(ys)
+      }
       for (column in self$archive$cols_y) {
         set(ys, j = column, value = ys[[column]] * self$surrogate_max_to_min[[column]])  # assume minimization
       }
