@@ -9,7 +9,7 @@
 #' @import lgr
 #' @import mlr3
 #' @import mlr3tuning
-#' @importFrom stats setNames runif dnorm pnorm quantile rexp
+#' @importFrom stats setNames runif dnorm pnorm quantile rexp sd
 #' @useDynLib mlr3mbo c_sms_indicator c_eps_indicator
 "_PACKAGE"
 
@@ -30,7 +30,9 @@ register_mlr3tuning = function() {
   register_namespace_callback(pkgname, "bbotk", register_bbotk)
   register_namespace_callback(pkgname, "mlr3tuning", register_mlr3tuning)
 
-  assign("lg", lgr::get_logger("bbotk"), envir = parent.env(environment()))
+  #https://github.com/mlr-org/bbotk/blob/ae6cac60f71b3c44ce1bb29669f5d06cddeb95d4/R/zzz.R#L20
+  lg = lgr::get_logger("mlr3/bbotk")
+  assign("lg", lg, envir = parent.env(environment()))
 
   if (Sys.getenv("IN_PKGDOWN") == "true") {
     lg$set_threshold("warn")
