@@ -219,19 +219,22 @@ expect_acqfunction = function(acqf) {
   expect_man_exists(acqf$man)
 }
 
-expect_rush_reset = function(rush, type = "kill") {
-  processes = rush$processes
-  rush$reset(type = type)
-  expect_list(rush$connector$command(c("KEYS", "*")), len = 0)
-  walk(processes, function(p) p$kill())
-}
-
 flush_redis = function() {
   config = redux::redis_config()
   r = redux::hiredis(config)
   r$FLUSHDB()
 }
 
+expect_rush_reset = function(rush, type = "kill") {
+  rush$reset(type = type)
+  Sys.sleep(1)
+  keys = rush$connector$command(c("KEYS", "*"))
+  if (!test_list(keys, len = 0)) {
+    stopf("Found keys in redis after reset: %s", keys)
+  }
+  mirai::daemons(0)
+}
+
 sortnames = function(x) {
   if (!is.null(names(x))) {
     x = x[order(names(x), decreasing = TRUE)]
