@@ -8,7 +8,7 @@ old_opts = options(
 old_opts = lapply(old_opts, function(x) if (is.null(x)) FALSE else x)
 
 lg_mlr3 = lgr::get_logger("mlr3")
-lg_bbotk = lgr::get_logger("bbotk")
+lg_bbotk = lgr::get_logger("mlr3/bbotk")
 lg_rush = lgr::get_logger("rush")
 
 old_threshold_mlr3 = lg_mlr3$threshold
