@@ -34,7 +34,6 @@ test_that("SurrogateLearnerCollection API works", {
   expect_equal(surrogate$predict_type, surrogate$learner[[1L]]$predict_type)
   expect_equal(surrogate$predict_type, surrogate$learner[[2L]]$predict_type)
   expect_error({surrogate$predict_type = "response"}, "is read-only")
-
 })
 
 test_that("predict_types are recognized", {
@@ -60,47 +59,12 @@ test_that("param_set", {
   inst = MAKE_INST(OBJ_1D_2, PS_1D, trm("evals", n_evals = 5L))
   surrogate = SurrogateLearnerCollection$new(learners = list(REGR_FEATURELESS, REGR_FEATURELESS$clone(deep = TRUE)), archive = inst$archive)
   expect_r6(surrogate$param_set, "ParamSet")
-  expect_setequal(surrogate$param_set$ids(), c("assert_insample_perf", "perf_measures", "perf_thresholds", "catch_errors", "impute_method"))
-  expect_equal(surrogate$param_set$class[["assert_insample_perf"]], "ParamLgl")
-  expect_equal(surrogate$param_set$class[["perf_measures"]], "ParamUty")
-  expect_equal(surrogate$param_set$class[["perf_thresholds"]], "ParamUty")
+  expect_setequal(surrogate$param_set$ids(), c("catch_errors", "impute_method"))
   expect_equal(surrogate$param_set$class[["catch_errors"]], "ParamLgl")
   expect_equal(surrogate$param_set$class[["impute_method"]], "ParamFct")
   expect_error({surrogate$param_set = list()}, regexp = "param_set is read-only.")
 })
 
-test_that("insample_perf", {
-  skip_if_not_installed("mlr3learners")
-  skip_if_not_installed("DiceKriging")
-  skip_if_not_installed("rgenoud")
-  inst = MAKE_INST(OBJ_1D_2, PS_1D, trm("evals", n_evals = 5L))
-  design = MAKE_DESIGN(inst)
-  inst$eval_batch(design)
-
-  surrogate = SurrogateLearnerCollection$new(learners = list(REGR_KM_DETERM, REGR_KM_DETERM$clone(deep = TRUE)), archive = inst$archive)
-  expect_error({surrogate$insample_perf = c(0, 0)}, regexp = "insample_perf is read-only.")
-  expect_error({surrogate$assert_insample_perf = 0}, regexp = "assert_insample_perf is read-only.")
-
-  surrogate$update()
-  expect_equal(surrogate$insample_perf, NaN)
-
-  surrogate$param_set$values$assert_insample_perf = TRUE
-  surrogate$param_set$values$perf_thresholds = c(0.5, 0.5)
-  surrogate$param_set$values$perf_measures = list(mlr_measures$get("regr.rsq"), mlr_measures$get("regr.rsq"))
-  surrogate$update()
-  expect_double(surrogate$insample_perf, lower = -Inf, upper = 1, any.missing = FALSE, len = 2L)
-  expect_equal(names(surrogate$insample_perf), map_chr(surrogate$param_set$values$perf_measures, "id"))
-
-  surrogate_constant = SurrogateLearnerCollection$new(learners = list(REGR_FEATURELESS, REGR_FEATURELESS$clone(deep = TRUE)), archive = inst$archive)
-  surrogate_constant$param_set$values$assert_insample_perf = TRUE
-  surrogate_constant$param_set$values$perf_thresholds = c(0.5, 0.5)
-  surrogate_constant$param_set$values$perf_measures = list(mlr_measures$get("regr.rsq"), mlr_measures$get("regr.rsq"))
-  expect_error(surrogate_constant$update(), regexp = "Current insample performance of the Surrogate Model does not meet the performance threshold")
-  expect_double(surrogate_constant$insample_perf, lower = -Inf, upper = 1, any.missing = FALSE, len = 2L)
-  expect_true(all(surrogate_constant$insample_perf <= 1e-3))
-  expect_equal(names(surrogate_constant$insample_perf), map_chr(surrogate$param_set$values$perf_measures, "id"))
-})
-
 test_that("unique in memory", {
   learner = REGR_FEATURELESS
   expect_error(SurrogateLearnerCollection$new(learners = list(learner, learner)), "Redundant Learners")
